---
annotations_creators:
- expert-generated
language_creators:
- expert-generated
languages:
- te
licenses:
- unknown
multilinguality:
- monolingual
size_categories:
- n<1K
source_datasets:
- original
task_categories:
- sequence-modeling
task_ids:
- language-modeling
paperswithcode_id: null
pretty_name: TeluguBooks
---

 # Dataset Card for [telugu_books]

 ## Table of Contents
 - [Dataset Description](#dataset-description)
   - [Dataset Summary](#dataset-summary)
   - [Supported Tasks](#supported-tasks-and-leaderboards)
   - [Languages](#languages)
 - [Dataset Structure](#dataset-structure)
   - [Data Instances](#data-instances)
   - [Data Fields](#data-instances)
   - [Data Splits](#data-instances)
 - [Dataset Creation](#dataset-creation)
   - [Curation Rationale](#curation-rationale)
   - [Source Data](#source-data)
   - [Annotations](#annotations)
   - [Personal and Sensitive Information](#personal-and-sensitive-information)
 - [Considerations for Using the Data](#considerations-for-using-the-data)
   - [Social Impact of Dataset](#social-impact-of-dataset)
   - [Discussion of Biases](#discussion-of-biases)
   - [Other Known Limitations](#other-known-limitations)
 - [Additional Information](#additional-information)
   - [Dataset Curators](#dataset-curators)
   - [Licensing Information](#licensing-information)
   - [Citation Information](#citation-information)

 ## Dataset Description

 - **Homepage:**

 [Telugu Books](https://www.kaggle.com/sudalairajkumar/telugu-nlp)

 - **Repository:**
 - **Paper:**
 - **Leaderboard:**
 - **Point of Contact:**

 ### Dataset Summary

This dataset is created by scraping telugu novels from teluguone.com this dataset can be used for nlp tasks like topic modeling, word embeddings, transfer learning etc

 ### Supported Tasks and Leaderboards

 [More Information Needed]

 ### Languages

TE - Telugu

 ## Dataset Structure

 ### Data Instances

 [More Information Needed]

 ### Data Fields

 - Text: Sentence from a novel

 ### Data Splits

 [More Information Needed]

 ## Dataset Creation

 ### Curation Rationale

 [More Information Needed]

 ### Source Data

 #### Initial Data Collection and Normalization

 [More Information Needed]

 #### Who are the source language producers?

 Anusha Motamarri

 ### Annotations

 #### Annotation process

 Anusha Motamarri

 #### Who are the annotators?

 Anusha Motamarri

 ### Personal and Sensitive Information

 [More Information Needed]

 ## Considerations for Using the Data

 ### Social Impact of Dataset

 [More Information Needed]

 ### Discussion of Biases

 [More Information Needed]

 ### Other Known Limitations

 [More Information Needed]

 ## Additional Information

 ### Dataset Curators

 [More Information Needed]

 ### Licensing Information

 [More Information Needed]

 ### Citation Information

 [More Information Needed]

### Contributions

Thanks to [@vinaykudari](https://github.com/vinaykudari) for adding this dataset.
